Package: AOV1R
Type: Package
Title: Inference in the Balanced One-Way ANOVA Model with Random Factor
Version: 0.1.0
Author: Stéphane Laurent
Maintainer: Stéphane Laurent <laurent_step@outlook.fr>
Description: Provides functions to perform statistical inference in the balanced one-way ANOVA model with a random factor: confidence intervals, prediction interval, and Weerahandi generalized pivotal quantities. References: Burdick & Graybill (1992, ISBN-13: 978-0824786441); Weerahandi (1995) <doi:10.1007/978-1-4612-0825-9>; Lin & Liao (2008) <doi:10.1016/j.jspi.2008.01.001>.
License: GPL-3
Encoding: UTF-8
LazyData: true
Depends: R (>= 2.10)
Imports: cellranger, purrr, stats, data.table, lazyeval, utils
RoxygenNote: 7.1.1
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2020-11-05 08:52:16 UTC; stla
Repository: CRAN
Date/Publication: 2020-11-10 10:00:08 UTC
Built: R 4.6.0; ; 2026-04-28 14:04:11 UTC; unix
