# Generated by roxygen2: do not edit by hand

S3method(confint,aov1r)
S3method(predict,aov1r)
S3method(print,confint.aov1r)
S3method(print,summary.aov1r)
S3method(summary,aov1r)
export(aov1r)
export(rGPQ)
export(simAOV1R)
import(data.table)
importFrom(cellranger,num_to_letter)
importFrom(lazyeval,f_eval_lhs)
importFrom(lazyeval,f_eval_rhs)
importFrom(lazyeval,f_lhs)
importFrom(lazyeval,f_rhs)
importFrom(purrr,map)
importFrom(stats,qf)
importFrom(stats,qt)
importFrom(stats,rchisq)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(utils,capture.output)
importFrom(utils,stack)
